window.Gleam.initSearch([{"doc":"juno","title":"juno","content":"&lt;!-- ![juno](https://raw.githubusercontent.com/massivefermion/bison/main/banner.png) --&gt;\n![juno](https://raw.githubusercontent.com/massivefermion/juno/main/banner.png)\n\n[![Package Version](https://img.shields.io/hexpm/v/juno)](https://hex.pm/packages/juno)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/juno)\n\n# juno \n\nJuno is a tool for decoding JSON in a more flexible way, which can be useful in situations where the exact structure of the data is not known but there are still patterns in it that need to be captured.\n\n## 🦋 Quick start\n\n```sh\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## 🦋 Installation\n\n```sh\ngleam add juno\n```\n\n## 🦋 Usage\n\n```gleam\nimport gleam/dynamic\nimport juno\n\npub type Entity {\n  Player(id: String, score: Int, eliminated: Bool)\n  Game(id: String, players: List(String), winner: String, prize: String)\n}\n\npub fn main() {\n  let json = &quot;{\n      \\&quot;2023-11-24\\&quot;: {\n        \\&quot;weather\\&quot;: \\&quot;rainy\\&quot;,\n        \\&quot;attending\\&quot;: {\n          \\&quot;anton\\&quot;: {\n            \\&quot;id\\&quot;: \\&quot;P36\\&quot;,\n            \\&quot;scores\\&quot;: [45, 55],\n            \\&quot;eliminated\\&quot;: true\n          },\n          \\&quot;vincent\\&quot;: {\n            \\&quot;id\\&quot;: \\&quot;P3\\&quot;,\n            \\&quot;score\\&quot;: 28,\n            \\&quot;eliminated\\&quot;: false\n          },\n          \\&quot;gerome\\&quot;: {\n            \\&quot;id\\&quot;: \\&quot;P6\\&quot;,\n            \\&quot;score\\&quot;: 15,\n            \\&quot;eliminated\\&quot;: false\n          },\n          \\&quot;irene\\&quot;: {\n            \\&quot;id\\&quot;: \\&quot;P10\\&quot;,\n            \\&quot;score\\&quot;: 21,\n            \\&quot;eliminated\\&quot;: false\n          }\n        },\n        \\&quot;14:00\\&quot;: {\n          \\&quot;id\\&quot;: \\&quot;G528\\&quot;, \n          \\&quot;players\\&quot;: [\n            \\&quot;P10\\&quot;,\n            \\&quot;P6\\&quot;\n          ],\n          \\&quot;winner\\&quot;: \\&quot;P10\\&quot;,\n          \\&quot;prize\\&quot;: \\&quot;vacation\\&quot;\n        },\n        \\&quot;16:00-&gt;21:00\\&quot;: [\n          {\n            \\&quot;id\\&quot;: \\&quot;G561\\&quot;, \n            \\&quot;players\\&quot;: [\n              \\&quot;P10\\&quot;,\n              \\&quot;P3\\&quot;\n            ],\n            \\&quot;winner\\&quot;: \\&quot;P10\\&quot;,\n            \\&quot;prize\\&quot;: \\&quot;toaster\\&quot;\n          },\n          {\n            \\&quot;id\\&quot;: \\&quot;G595\\&quot;, \n            \\&quot;players\\&quot;: [\n              \\&quot;P3\\&quot;,\n              \\&quot;P6\\&quot;\n            ],\n            \\&quot;winner\\&quot;: \\&quot;P3\\&quot;,\n            \\&quot;prize\\&quot;: \\&quot;car\\&quot;\n          } \n        ]\n      }\n    }&quot;\n\n  let active_player_decoder =\n    dynamic.decode3(\n      Player,\n      dynamic.field(&quot;id&quot;, dynamic.string),\n      dynamic.field(&quot;score&quot;, dynamic.int),\n      dynamic.field(&quot;eliminated&quot;, dynamic.bool),\n    ) \n\n  let game_decoder =\n    dynamic.decode4(\n      Game,\n      dynamic.field(&quot;id&quot;, dynamic.string),\n      dynamic.field(&quot;players&quot;, dynamic.list(dynamic.string)),\n      dynamic.field(&quot;winner&quot;, dynamic.string),\n      dynamic.field(&quot;prize&quot;, dynamic.string),\n    )\n\n  juno.decode(json, [active_player_decoder, game_decoder])\n}\n```","url":"index.html"},{"doc":"juno","title":"Value","content":"pub type Value(a) {\n  Null\n  Int(Int)\n  Custom(a)\n  Bool(Bool)\n  Float(Float)\n  String(String)\n  Array(List(Value(a)))\n  Object(map.Map(String, Value(a)))\n}\n\nNull\n\n\nInt(Int)\n\n\nCustom(a)\n\n\nBool(Bool)\n\n\nFloat(Float)\n\n\nString(String)\n\n\nArray(List(Value(a)))\n\n\nObject(map.Map(String, Value(a)))\n\n\nSynonyms:\njuno.Value\njuno Value","url":"juno.html#Value"},{"doc":"juno","title":"decode","content":"pub fn decode(\n  json: String,\n  custom_decoders: List(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  ),\n) -&gt; Result(Value(a), gleam/json.DecodeError)\n\nSynonyms:\njuno.decode\njuno decode","url":"juno.html#decode"},{"doc":"juno","title":"decode_object","content":"pub fn decode_object(\n  json: String,\n  custom_decoders: List(\n    fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  ),\n) -&gt; Result(Value(a), gleam/json.DecodeError)\n\nSynonyms:\njuno.decode_object\njuno decode_object","url":"juno.html#decode_object"},{"doc":"juno","title":"juno","content":"","url":"juno.html"}]);